@@ -19,7 +19,9 @@ class SFTPFile(NetFile):
             host_auth: Dict[str, Tuple[str, str]] = None,
     ):
         super().__init__()
-        if start_bytes < 0 or length < 0:
+        if start_bytes is not None and start_bytes < 0:
+            raise InvalidFileRangeError()
+        if length is not None and length < 0:
             raise InvalidFileRangeError()
 
         self._url = url
